"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Head = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const useSiteMetadata_1 = require("gatsby-plugin-jaen/hooks/useSiteMetadata");
const getSchemaOrg_js_1 = require("./getSchemaOrg.js");
const Head = props => {
    const siteMetadata = (0, useSiteMetadata_1.useSiteMetadata)();
    const defaultTitle = props.location.pathname;
    const jaenPageMetadata = props.jaenPageMetadata || {};
    const title = jaenPageMetadata.title ||
        props.data.jaenPage?.jaenPageMetadata?.title ||
        siteMetadata?.title ||
        defaultTitle;
    const description = jaenPageMetadata.description ||
        props.data.jaenPage?.jaenPageMetadata?.description ||
        siteMetadata?.description;
    const image = jaenPageMetadata.image ||
        props.data.jaenPage?.jaenPageMetadata?.image ||
        siteMetadata?.image;
    const url = `${siteMetadata?.siteUrl}${props.location.pathname}`;
    const isBlogPost = jaenPageMetadata.isBlogPost ||
        props.data.jaenPage?.jaenPageMetadata?.isBlogPost ||
        false;
    const datePublished = jaenPageMetadata.datePublished ||
        props.data.jaenPage?.jaenPageMetadata?.datePublished ||
        false;
    const fbAppID = siteMetadata?.social?.fbAppID;
    const twitter = siteMetadata?.social?.twitter;
    const schemaOrgJSON = (0, getSchemaOrg_js_1.getSchemaOrg)({
        author: siteMetadata?.author,
        datePublished,
        defaultTitle,
        description: description || '',
        image: image || '',
        isBlogPost,
        organization: siteMetadata?.organization,
        title,
        siteUrl: siteMetadata?.siteUrl || '',
        url
    });
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("title", { id: "title", children: title }), (0, jsx_runtime_1.jsx)("meta", { id: "meta-description", name: "description", content: description }), (0, jsx_runtime_1.jsx)("meta", { id: "meta-image", name: "image", content: image }), (0, jsx_runtime_1.jsx)("link", { id: "canonical-link", rel: "canonical", href: url }), (0, jsx_runtime_1.jsx)("meta", { id: "og-url", property: "og:url", content: url }), isBlogPost ? ((0, jsx_runtime_1.jsx)("meta", { id: "og-type", property: "og:type", content: "article" })) : null, (0, jsx_runtime_1.jsx)("meta", { id: "og-title", property: "og:title", content: title }), (0, jsx_runtime_1.jsx)("meta", { id: "og-description", property: "og:description", content: description }), (0, jsx_runtime_1.jsx)("meta", { id: "og-image", property: "og:image", content: image }), (0, jsx_runtime_1.jsx)("meta", { id: "fb-app-id", property: "fb:app_id", content: fbAppID }), (0, jsx_runtime_1.jsx)("meta", { id: "twitter-card", name: "twitter:card", content: "summary_large_image" }), (0, jsx_runtime_1.jsx)("meta", { id: "twitter-creator", name: "twitter:creator", content: twitter }), (0, jsx_runtime_1.jsx)("meta", { id: "twitter-title", name: "twitter:title", content: title }), (0, jsx_runtime_1.jsx)("meta", { id: "twitter-description", name: "twitter:description", content: description }), (0, jsx_runtime_1.jsx)("meta", { id: "twitter-image", name: "twitter:image", content: image }), (0, jsx_runtime_1.jsx)("script", { id: "schema-org", type: "application/ld+json", children: JSON.stringify(schemaOrgJSON) }), props.children] }));
};
exports.Head = Head;
//# sourceMappingURL=Head.js.map