"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processIMAtoNodes = exports.processSections = exports.processPage = void 0;
const gatsby_source_filesystem_1 = require("gatsby-source-filesystem");
const processPage = async ({ page, ...rest }) => {
    if (page.jaenFields) {
        for (const [type, field] of Object.entries(page.jaenFields)) {
            await (0, exports.processIMAtoNodes)({
                node: page,
                type,
                field,
                ...rest
            });
        }
    }
    page.sections = page.sections || [];
    await (0, exports.processSections)({
        sections: page.sections,
        ...rest
    });
    page.jaenFiles = page.jaenFiles || [];
};
exports.processPage = processPage;
const processSections = async ({ sections, ...rest }) => {
    for (const section of sections) {
        for (const item of section.items) {
            if (item.jaenFields) {
                for (const [type, field] of Object.entries(item.jaenFields)) {
                    await (0, exports.processIMAtoNodes)({
                        node: item,
                        type,
                        field,
                        ...rest
                    });
                }
            }
            item.sections = item.sections || [];
            await (0, exports.processSections)({
                sections: item.sections,
                ...rest
            });
        }
    }
};
exports.processSections = processSections;
const processIMAtoNodes = async ({ node, type, field, ...rest }) => {
    const createJaenFile = async (url) => {
        const fileNode = await (0, gatsby_source_filesystem_1.createRemoteFileNode)({
            url,
            parentNodeId: node.id,
            ...rest
        });
        const fileNodeId = fileNode.id;
        if (!node.jaenFiles) {
            node.jaenFiles = [];
        }
        node.jaenFiles.push(fileNodeId);
        return fileNodeId;
    };
    switch (type) {
        case 'IMA:ImageField':
            for (const [name, v] of Object.entries(field)) {
                try {
                    if (v.value) {
                        const { internalImageUrl } = v.value;
                        console.log('iamProcess', name, type, internalImageUrl);
                        if (internalImageUrl) {
                            const fileNodeId = await createJaenFile(internalImageUrl);
                            v.value.imageId = fileNodeId;
                        }
                    }
                }
                catch (error) {
                    console.error(`${name} is not a valid IMA field`, error);
                }
            }
            break;
        default:
            break;
    }
};
exports.processIMAtoNodes = processIMAtoNodes;
//# sourceMappingURL=iam-process.js.map