"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildSearchIndex = void 0;
const slugify_1 = __importDefault(require("@sindresorhus/slugify"));
const buildSearchIndex = async (nodes) => {
    const searchIndex = {};
    for (const node of nodes) {
        const pagePath = node.path;
        if (!pagePath) {
            continue;
        }
        const title = node.jaenPageMetadata?.title || pagePath;
        const description = node.jaenPageMetadata?.description || '';
        const data = {
            '': description
        };
        if (node.jaenFields) {
            const mdxField = node.jaenFields['IMA:MdxField'];
            const textField = node.jaenFields['IMA:TextField'];
            if (mdxField) {
                let currentHeading = null;
                const duplicationRecord = {};
                const buildHeading = (value) => {
                    let slug = (0, slugify_1.default)(value);
                    if (duplicationRecord[slug]) {
                        slug += `-${duplicationRecord[slug]}`;
                        duplicationRecord[slug] += 1;
                    }
                    else {
                        duplicationRecord[slug] = 1;
                    }
                    return `${slug}#${value}`;
                };
                for (const value of Object.values(mdxField)) {
                    const mdast = value.value;
                    for (const node of mdast.children) {
                        if (node.type === 'heading') {
                            const element = node.children[0];
                            if (element) {
                                if (element.type === 'text') {
                                    currentHeading = buildHeading(element.value);
                                    data[currentHeading] = '';
                                }
                            }
                        }
                        else if (node.type === 'paragraph') {
                            const element = node.children[0];
                            if (element) {
                                if (element.type === 'text') {
                                    if (currentHeading) {
                                        data[currentHeading] += `${element.value}\n`;
                                    }
                                    else {
                                        data[''] += `${element.value}\n`;
                                    }
                                }
                            }
                        }
                    }
                }
            }
            if (textField) {
                for (const value of Object.values(textField)) {
                    const isHeading = value.props?.as &&
                        ['h1', 'h2', 'h3', 'h4', 'h5', 'h6'].includes(value.props.as);
                    const id = value.props?.id;
                    const relatedName = value.props?.relatedName;
                    const textValue = value.value || '';
                    if (isHeading && id) {
                        data[`${id}#${value.value || ''}`] = '';
                    }
                    else if (relatedName) {
                        const realtedField = textField[relatedName];
                        if (realtedField) {
                            const relatedId = realtedField.props?.id;
                            const relatedValue = realtedField.value;
                            if (relatedId) {
                                data[`${relatedId}#${relatedValue}`] += `${textValue}\n`;
                            }
                        }
                    }
                    else {
                        data[''] += `${textValue}\n`;
                    }
                }
            }
        }
        searchIndex[pagePath] = {
            id: node.id,
            type: node.type,
            title,
            data
        };
    }
    return searchIndex;
};
exports.buildSearchIndex = buildSearchIndex;
//# sourceMappingURL=build-search-index.js.map